@@ -12,10 +12,12 @@
 #
 ##############################################################################
 
-import unittest
 import doctest
+import unittest
+
 import samplelayers
 
+
 layername = 'samplelayers.Layer12'
 layer = samplelayers.Layer12
 
@@ -135,9 +137,10 @@ def test_z1(self):
 
 def test_suite():
     suite = unittest.TestSuite()
-    suite.addTest(unittest.makeSuite(TestA))
-    suite.addTest(unittest.makeSuite(TestB))
-    suite.addTest(unittest.makeSuite(TestNotMuch))
+    suite.addTest(unittest.defaultTestLoader.loadTestsFromTestCase(TestA))
+    suite.addTest(unittest.defaultTestLoader.loadTestsFromTestCase(TestB))
+    suite.addTest(
+        unittest.defaultTestLoader.loadTestsFromTestCase(TestNotMuch))
     s = doctest.DocTestSuite(setUp=setUp)
     s.layer = layer
     suite.addTest(s)
